/*
   Copyright (c) 2003, 2013, Oracle and/or its affiliates. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA */


#ifndef PRIO_H
#define PRIO_H

#define JAM_FILE_ID 280


enum JobBufferLevel {
  JBA = 0, 
  JBB = 1, 
  JBC = 2, 
  JBD = 3, LEVEL_IDLE = 3,
  JB_LEVELS,
  ILLEGAL_JB_LEVEL
};

typedef JobBufferLevel Priority;



#undef JAM_FILE_ID

#endif
